<?php

namespace Teknisa\CRM\Factory;

use Doctrine\ORM\EntityManager;

class CRMAssistentesFactory {
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        $this->connection = $entityManager->getConnection();
    }
    
    public function getAssistenciaNumber($params) {
        $sql = "SELECT NRASSISTENCIA
                FROM CRM_ASSISTENCIA
                WHERE NROPERPRINCIPAL = :NROPERPRINCIPAL
                  AND NROPERASSIST    = :NROPERASSIST
                  AND NRORG           = :NRORG";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    public function saveNewAssist($params) {
        $sql = "INSERT INTO CRM_ASSISTENCIA
                (NRASSISTENCIA, NROPERPRINCIPAL, NROPERASSIST)
                VALUES
                (:NRASSISTENCIA, :NROPERPRINCIPAL, :NROPERASSIST)";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function activateAssist($params) {
        $sql = "UPDATE CRM_ASSISTENCIA
                   SET IDATIVO      = 'S',
                       DTULTATU     = SYSDATE,
                       CDOPERULTATU = :CDOPERADOR,
                       NRORGULTATU  = :NRORG
                       
                WHERE NRASSISTENCIA = :NRASSISTENCIA
                  AND NRORG         = :NRORG";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function removeAssist($params) {
        $sql = "UPDATE CRM_ASSISTENCIA
                   SET IDATIVO      = 'N',
                       DTULTATU     = SYSDATE,
                       CDOPERULTATU = :CDOPERADOR,
                       NRORGULTATU  = :NRORGOPER
                       
                WHERE NRASSISTENCIA = :NRASSISTENCIA
                  AND NRORG         = :NRORG";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    public function checkIfCanEditOrEvolParc($params) {
        $sql = "SELECT 
                  (CASE
                    WHEN COUNT(1) > 0 
                      THEN 'S'
                    ELSE 'N'
                  END) IDCANEDIT
                FROM 
                  PARCNEGOCIO PARC
                  JOIN CRM_STATUSPARC STAT
                    ON STAT.NRPARCNEGOCIO = PARC.NRPARCNEGOCIO
                      AND STAT.NRORG = PARC.NRORG
                      AND STAT.CRM_NRORGTRAB = :CRM_NRORGTRAB
                WHERE 
                  PARC.NRPARCNEGOCIO = :NRPARCNEGOCIO
                  AND PARC.NRORG = :NRORG
                  AND (STAT.CDOPERRESP = :CDOPERADOR OR :NRPARCOPER IN (SELECT 
                                                                          NROPERASSIST
                                                                        FROM 
                                                                          CRM_ASSISTENCIA AST
                                                                        WHERE 
                                                                          NROPERPRINCIPAL = (SELECT 
                                                                                               NRPARCNEGOCIO
                                                                                             FROM 
                                                                                               OPERADOR OPER
                                                                                             WHERE 
                                                                                               CDOPERADOR = STAT.CDOPERRESP
                                                                                               AND OPER.NRORG = AST.NRORG)
                                                                          AND AST.IDATIVO = 'S'
                                                                          AND AST.NRORG = PARC.NRORG))";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    public function checkParamEditParcIsActive($params) {
        $sql = "SELECT IDASSISTAPENAS
                FROM CRM_PARAMETRIZACAO
                WHERE NRORG = :NRORG
                  AND ROWNUM = 1";
                 
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
        return $std->fetchAll();
    }
}