/* Tabela COMANDAFOS: TABELA DE COMANDA */
/* Descrio A trigger insere registros na tabela LOGOPERAVND a partir de alteraes na tabela COMANDAFOS */
/* Objetivo Gerar um log que vai registrar as alteraes na COMANDAFOS,
             utilizando a tabela de Logs de Operaes do VND*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_VND_COMANDAFOS' AND
                 TYPE   = 'TR' 	               AND
	              U.UID  = O.UID           AND
	              U.NAME = USER)
DROP TRIGGER LOG_VND_COMANDAFOS 
GO


CREATE TRIGGER LOG_VND_COMANDAFOS 
ON COMANDAFOS 
FOR INSERT, UPDATE, DELETE
AS
  DECLARE @V_DSREMOTEADDR VARCHAR(15);
  DECLARE @V_DSREMOTEHOST VARCHAR(15);
  DECLARE @V_DSSERVERRDM  VARCHAR(20);
  DECLARE @V_DSSERVMETHOD VARCHAR(30);
  DECLARE @V_DSREMOTEOPER VARCHAR(12);
  DECLARE @V_DESC         VARCHAR(500);
  DECLARE @V_ITPESQ       VARCHAR(40);
  DECLARE @V_NMOPERADOR   VARCHAR(40);
  DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/

  DECLARE @V_ID_COMANDO    VARCHAR(1);

  DECLARE @V_NEW_CDFILIAL            varchar(4);
  DECLARE @V_NEW_CDLOJA              varchar(10);
  DECLARE @V_NEW_DSCOMANDAFOS        varchar(50);
  DECLARE @V_NEW_DSOBSCOMANDAFOS     varchar(100);
  DECLARE @V_NEW_DTSITCOMANDAFOS     datetime;
  DECLARE @V_NEW_CDOPERADOR          varchar(12);
  DECLARE @V_NEW_IDSITCOMANDAFOS     char(1);
  DECLARE @V_NEW_DTULTATUCOMANDA     datetime;

  DECLARE @V_OLD_CDFILIAL            varchar(4);
  DECLARE @V_OLD_CDLOJA              varchar(10);
  DECLARE @V_OLD_DSCOMANDAFOS        varchar(50);
  DECLARE @V_OLD_DSOBSCOMANDAFOS     varchar(100);
  DECLARE @V_OLD_DTSITCOMANDAFOS     datetime;
  DECLARE @V_OLD_CDOPERADOR          varchar(12);
  DECLARE @V_OLD_IDSITCOMANDAFOS     char(1);
  DECLARE @V_OLD_DTULTATUCOMANDA     datetime;

BEGIN
/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC   = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO @P_NMUSUARIO = @V_NMOPERADOR OUTPUT;
   SET @V_NMOPERADOR = ISNULL(@V_NMOPERADOR, ' ');

   EXEC WEBTUNNING  @P_DSREMOTEADDR = @V_DSREMOTEADDR OUTPUT,
                    @P_DSREMOTEHOST = @V_DSREMOTEHOST OUTPUT,
                    @P_DSSERVERRDM  = @V_DSSERVERRDM OUTPUT,
                    @P_DSSERVMETHOD = @V_DSSERVMETHOD OUTPUT,
                    @P_DSREMOTEOPER = @V_DSREMOTEOPER OUTPUT;

   DECLARE C_CURSOR CURSOR FOR
     SELECT
     'D'   ID_COMANDO,
           NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,

           CDFILIAL,
           CDLOJA,
           DSCOMANDAFOS,
           DSOBSCOMANDAFOS,
           DTSITCOMANDAFOS,
           CDOPERADOR,
           IDSITCOMANDAFOS,
           DTULTATUCOMANDA

     FROM
           DELETED
     WHERE     
           CDFILIAL+CDLOJA+DSCOMANDAFOS NOT IN (SELECT CDFILIAL+CDLOJA+DSCOMANDAFOS FROM INSERTED)
     UNION ALL

     SELECT
     'U'   IDCOMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDLOJA,
           INSERTED.DSCOMANDAFOS,
           INSERTED.DSOBSCOMANDAFOS,
           INSERTED.DTSITCOMANDAFOS,
           INSERTED.CDOPERADOR,
           INSERTED.IDSITCOMANDAFOS,
           INSERTED.DTULTATUCOMANDA,
           DELETED.CDFILIAL,
           DELETED.CDLOJA,
           DELETED.DSCOMANDAFOS,
           DELETED.DSOBSCOMANDAFOS,
           DELETED.DTSITCOMANDAFOS,
           DELETED.CDOPERADOR,
           DELETED.IDSITCOMANDAFOS,
           DELETED.DTULTATUCOMANDA 
     
     FROM
           INSERTED,
           DELETED
     WHERE     
           INSERTED.CDFILIAL =     DELETED.CDFILIAL AND
           INSERTED.CDLOJA   =     DELETED.CDLOJA   AND
           INSERTED.DSCOMANDAFOS = DELETED.DSCOMANDAFOS
     UNION ALL

     SELECT
     'I'   IDCOMANDO,
           INSERTED.CDFILIAL,
           INSERTED.CDLOJA,
           INSERTED.DSCOMANDAFOS,
           INSERTED.DSOBSCOMANDAFOS,
           INSERTED.DTSITCOMANDAFOS,
           INSERTED.CDOPERADOR,
           INSERTED.IDSITCOMANDAFOS,
           INSERTED.DTULTATUCOMANDA,

           NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL

     FROM
           INSERTED
     WHERE     
           CDFILIAL+CDLOJA+DSCOMANDAFOS NOT IN (SELECT CDFILIAL+CDLOJA+DSCOMANDAFOS FROM DELETED)

     OPEN C_CURSOR;
           FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,

                                         @V_NEW_CDFILIAL,@V_NEW_CDLOJA,@V_NEW_DSCOMANDAFOS,@V_NEW_DSOBSCOMANDAFOS,
                                         @V_NEW_DTSITCOMANDAFOS,@V_NEW_CDOPERADOR,@V_NEW_IDSITCOMANDAFOS,@V_NEW_DTULTATUCOMANDA,

                                         @V_OLD_CDFILIAL,@V_OLD_CDLOJA,@V_OLD_DSCOMANDAFOS,@V_OLD_DSOBSCOMANDAFOS,
                                         @V_OLD_DTSITCOMANDAFOS,@V_OLD_CDOPERADOR,@V_OLD_IDSITCOMANDAFOS,@V_OLD_DTULTATUCOMANDA


    WHILE (@@FETCH_STATUS = 0) BEGIN
 
       IF @V_ID_COMANDO= 'U' /*UPDATE*/ BEGIN
		IF ISNULL(@V_NEW_CDFILIAL,'NULL') <> ISNULL(@V_OLD_CDFILIAL,'NULL') BEGIN
			SET @V_DESC   = 'Filial ' + ISNULL(@V_NEW_CDFILIAL,'');
		END;
		IF ISNULL(@V_NEW_CDLOJA,'NULL') <> ISNULL(@V_OLD_CDLOJA,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Loja ' + ISNULL(@V_NEW_CDLOJA,'');
		END;
		IF ISNULL(@V_NEW_DSCOMANDAFOS,'NULL') <> ISNULL(@V_OLD_DSCOMANDAFOS,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd Comanda ' + ISNULL(@V_NEW_DSCOMANDAFOS,'');
		END;
		IF ISNULL(@V_NEW_DSOBSCOMANDAFOS,'NULL') <> ISNULL(@V_OLD_DSOBSCOMANDAFOS,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Observao Comanda ' + ISNULL(@V_NEW_DSOBSCOMANDAFOS,'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTSITCOMANDAFOS),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTSITCOMANDAFOS),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Dt situao ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTSITCOMANDAFOS),'');
		END;
		IF ISNULL(@V_NEW_CDOPERADOR,'NULL') <> ISNULL(@V_OLD_CDOPERADOR,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Cd Operador ' + ISNULL(@V_NEW_CDOPERADOR,'');
		END;
		IF ISNULL(@V_NEW_IDSITCOMANDAFOS,'NULL') <> ISNULL(@V_OLD_IDSITCOMANDAFOS,'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Situao Comanda ' + ISNULL(@V_NEW_IDSITCOMANDAFOS,'');
		END;
		IF ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUCOMANDA),'NULL') <> ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATUCOMANDA),'NULL') BEGIN
            SET @V_DESC  = ISNULL(@V_DESC,'') + '  Dt Ult Atu Comanda ' + ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUCOMANDA),'');
		END;
          SET @V_IDTIPOOPER = '2';
       END;
       IF @V_ID_COMANDO= 'I' /*INSERO*/ BEGIN
          SET @V_DESC   = 'Filial '                 +  ISNULL(@V_NEW_CDFILIAL,''    )        +
                          ' Loja  '                 +  ISNULL(@V_NEW_CDLOJA,''      )        +
                          ' Cd Comanda '            +  ISNULL(@V_NEW_DSCOMANDAFOS,'' )       +
                          ' Observao Comanda  '   +  ISNULL(@V_NEW_DSOBSCOMANDAFOS,'')     +
                          ' Dt situao  '          +  ISNULL(CONVERT(VARCHAR,@V_NEW_DTSITCOMANDAFOS),''  )   +
                          ' Cd Operador '           +  ISNULL(@V_NEW_CDOPERADOR,''  )        +
                          ' Situao Comanda '      +  ISNULL(@V_NEW_IDSITCOMANDAFOS,'')     +
                          ' Dt Ult Atu Comanda '    +  ISNULL(CONVERT(VARCHAR,@V_NEW_DTULTATUCOMANDA),'');
          SET @V_IDTIPOOPER = '1';
       END; 
       IF @V_ID_COMANDO= 'D' /*DELEO*/  BEGIN
          SET @V_DESC   = 'Filial '                 +  ISNULL(@V_OLD_CDFILIAL,''    )        + 
                          ' Loja  '                 +  ISNULL(@V_OLD_CDLOJA,''      )        + 
                          ' Cd Comanda '            +  ISNULL(@V_OLD_DSCOMANDAFOS,'' )       + 
                          ' Observao Comanda  '   +  ISNULL(@V_OLD_DSOBSCOMANDAFOS,'')     + 
                          ' Dt situao  '          +  ISNULL(CONVERT(VARCHAR,@V_OLD_DTSITCOMANDAFOS),''  )  + 
                          ' Cd Operador '           +  ISNULL(@V_OLD_CDOPERADOR,''  )        + 
                          ' Situao Comanda '      +  ISNULL(@V_OLD_IDSITCOMANDAFOS,'')     +
                          ' Dt Ult Atu Comanda '    +  ISNULL(CONVERT(VARCHAR,@V_OLD_DTULTATUCOMANDA),'');
          SET @V_IDTIPOOPER = '3';
       END;
       IF  (@V_IDTIPOOPER <> '') BEGIN
          IF @V_DESC IS NOT NULL BEGIN
             SET @V_ITPESQ =  ISNULL(@V_NEW_CDFILIAL+@V_NEW_CDLOJA+@V_NEW_DSCOMANDAFOS,@V_OLD_CDFILIAL+@V_OLD_CDLOJA+@V_OLD_DSCOMANDAFOS);
             SET @V_DESC = SUBSTRING(@V_DESC, 1, 300);
             INSERT INTO LOGOPERAVND
                    (NMTABELAVND, DTOPERACAOVND, NMRESPOPERVND, IDTIPOOPERVND, DSOPERACAOVND,
                     CDPESQITEMVND, DSRDMUSUOPERVND, DSENDUSUOPERVND, DSNMUSUOPERVND, DSMETUSUOPERVND,
                     CDORESPOPERVND, CDFILLOGOPERVND)
             VALUES ('COMANDAFOS',GETDATE(), ISNULL(@V_NMOPERADOR,' '), @V_IDTIPOOPER, @V_DESC, @V_ITPESQ,
                     @V_DSSERVERRDM, @V_DSREMOTEADDR, @V_DSREMOTEHOST, @V_DSSERVMETHOD, @V_DSREMOTEOPER,
                     ISNULL(@V_NEW_CDFILIAL,@V_OLD_CDFILIAL));
          END;
       END;
       FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,

                                     @V_NEW_CDFILIAL,@V_NEW_CDLOJA,@V_NEW_DSCOMANDAFOS,@V_NEW_DSOBSCOMANDAFOS,
                                     @V_NEW_DTSITCOMANDAFOS,@V_NEW_CDOPERADOR,@V_NEW_IDSITCOMANDAFOS,@V_NEW_DTULTATUCOMANDA,

                                     @V_OLD_CDFILIAL,@V_OLD_CDLOJA,@V_OLD_DSCOMANDAFOS,@V_OLD_DSOBSCOMANDAFOS,
                                     @V_OLD_DTSITCOMANDAFOS,@V_OLD_CDOPERADOR,@V_OLD_IDSITCOMANDAFOS,@V_OLD_DTULTATUCOMANDA

   SET @V_DESC   = '';
   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_VND_COMANDAFOS','5.20.001';
GO 